/***********************************
 * Code for a simple matching model
 ***********************************/


var n, u, a_w, a_f, w, theta, p, v; //eight variables
varexo epspt;//one shock

parameters beta, mu, b, kappa, eta, rho, lambda, alpha, theta_ss, n_ss, u_ss,
a_w_ss, a_f_ss, w_ss, p_ss, v_ss ;

/**************
*parameter valus
***************/

beta=0.9901;//0.9881;//discount factor
lambda=0.069;//0.09;//separation rate (set to the data average 00-07)
theta_ss=0.54;//labour market tightness (set to the data average 00-07)
a_w_ss=1.05;//steady-state job finding rate (set to the data average 00-07)
alpha=0.72;//power for workers in matching function (follow Shimer 2005)
mu=a_w_ss/(theta_ss^(1-alpha));//matching function parameter
eta = 0.5;//0.72;//0.72;//0.72;//bargining power parameter for workers
b=0.4;//0.4;//0.4; // unemployment benefits

sigmapt=0.0165;//0.00115; //standard deviation of productivity shocks
rho = 0.9;//persistence of the productivity shock
p_ss=1;//output or productivity

// computing steady-state values for other variables

a_f_ss=a_w_ss/theta_ss;
u_ss=lambda/(lambda+a_w_ss);
n_ss=1-u_ss;
kappa=(beta*(1-eta)*(p_ss-b))/(((1-beta*(1-lambda))/a_f_ss)+beta*eta*theta_ss);
w_ss=(1-eta)*b+eta*(p_ss+kappa*theta_ss);
v_ss=theta_ss*u_ss;
f_ss=a_w_ss;

model;

log(p) = rho*log(p(-1)) + epspt;//shock process

n=(1-lambda)*n(-1)+a_w*u(-1); // law of motion of employment

n=1-u; 

a_w=mu*theta^(1-alpha);//job finding rate

w=(1-eta)*b+eta*(p+kappa*theta);//wage equation

kappa/a_f=beta*(p(+1)-w(+1)+(1-lambda)*kappa/a_f(+1)); //job creation equation

a_f=mu*theta^(-alpha);//vacancy filling rate

v=theta*u; //number of vacancies


end;

initval;
theta=theta_ss;
w=w_ss;
u=u_ss;
n=n_ss;
p=p_ss;
a_w=a_w_ss;
a_f=a_f_ss;
v=v_ss;

end;

steady;
check;

shocks;
var epspt;   stderr sigmapt;
end;

//stoch_simul;

stoch_simul(irf = 40, periods= 212,
            simul_replic = 1000);

%--------------------------------------------------------------------------
% Filtered moments
%--------------------------------------------------------------------------

logu=log(u); logv=log(v); logp=log(p);
[~,hpu]=hpfilter(logu,100000);
[~,hpv]=hpfilter(logv,100000);
[~,hpp]=hpfilter(logp,100000);

filtered_stds = {'u', 'v',  'p'; std(hpu), std(hpv), std(hpp)}
filtered_corr = {'uv', ; corr(hpu(1:end),hpv(1:end))}